@@ -4,4 +4,6 @@ from . import views
 
 router = routers.DefaultRouter()
 router.register("torrents", views.TorrentViewSet)
+router.register("torrentclients", views.TorrentClientViewSet)
+router.register("jobs", views.JobViewSet)
 urlpatterns = router.urls
